define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "toto čtvrtletí",
	"field-quarter-short-relative+1": "příští čtvrtletí",
	"field-tue-relative+-1": "minulé úterý",
	"field-year": "rok",
	"field-wed-relative+0": "tuto středu",
	"field-wed-relative+1": "příští středu",
	"field-minute": "minuta",
	"field-month-narrow-relative+-1": "minulý měs.",
	"field-tue-narrow-relative+0": "toto úterý",
	"field-tue-narrow-relative+1": "příští úterý",
	"field-day-short-relative+-1": "včera",
	"field-thu-short-relative+0": "tento čtvrtek",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "dnes",
	"field-day-short-relative+-2": "předevčírem",
	"field-thu-short-relative+1": "příští čtvrtek",
	"field-day-relative+1": "zítra",
	"field-week-narrow-relative+0": "tento týd.",
	"field-day-relative+2": "pozítří",
	"field-week-narrow-relative+1": "příští týd.",
	"field-wed-narrow-relative+-1": "minulou středu",
	"field-year-narrow": "r.",
	"field-era-short": "letop.",
	"field-year-narrow-relative+0": "tento rok",
	"field-tue-relative+0": "toto úterý",
	"field-year-narrow-relative+1": "příští rok",
	"field-tue-relative+1": "příští úterý",
	"field-weekdayOfMonth": "den týdne v měsíci",
	"field-second-short": "s",
	"dateFormatItem-MMMd": "d. M.",
	"field-weekdayOfMonth-narrow": "d. týd. v měs.",
	"field-week-relative+0": "tento týden",
	"field-month-relative+0": "tento měsíc",
	"field-week-relative+1": "příští týden",
	"field-month-relative+1": "příští měsíc",
	"field-sun-narrow-relative+0": "tuto neděli",
	"field-mon-short-relative+0": "toto pondělí",
	"field-sun-narrow-relative+1": "příští neděli",
	"field-mon-short-relative+1": "příští pondělí",
	"field-second-relative+0": "nyní",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"eraNames": [
		"Taika (645–650)",
		"Hakuchi (650–671)",
		"Hakuhō (672–686)",
		"Shuchō (686–701)",
		"Taihō (701–704)",
		"Keiun (704–708)",
		"Wadō (708–715)",
		"Reiki (715–717)",
		"Yōrō (717–724)",
		"Jinki (724–729)",
		"Tenpyō (729–749)",
		"Tenpyō-kampō (749-749)",
		"Tenpyō-shōhō (749-757)",
		"Tenpyō-hōji (757-765)",
		"Tenpyō-jingo (765-767)",
		"Jingo-keiun (767-770)",
		"Hōki (770–780)",
		"Ten-ō (781-782)",
		"Enryaku (782–806)",
		"Daidō (806–810)",
		"Kōnin (810–824)",
		"Tenchō (824–834)",
		"Jōwa (834–848)",
		"Kajō (848–851)",
		"Ninju (851–854)",
		"Saikō (854–857)",
		"Ten-an (857-859)",
		"Jōgan (859–877)",
		"Gangyō (877–885)",
		"Ninna (885–889)",
		"Kanpyō (889–898)",
		"Shōtai (898–901)",
		"Engi (901–923)",
		"Enchō (923–931)",
		"Jōhei (931–938)",
		"Tengyō (938–947)",
		"Tenryaku (947–957)",
		"Tentoku (957–961)",
		"Ōwa (961–964)",
		"Kōhō (964–968)",
		"Anna (968–970)",
		"Tenroku (970–973)",
		"Ten’en (973–976)",
		"Jōgen (976–978)",
		"Tengen (978–983)",
		"Eikan (983–985)",
		"Kanna (985–987)",
		"Eien (987–989)",
		"Eiso (989–990)",
		"Shōryaku (990–995)",
		"Chōtoku (995–999)",
		"Chōhō (999–1004)",
		"Kankō (1004–1012)",
		"Chōwa (1012–1017)",
		"Kannin (1017–1021)",
		"Jian (1021–1024)",
		"Manju (1024–1028)",
		"Chōgen (1028–1037)",
		"Chōryaku (1037–1040)",
		"Chōkyū (1040–1044)",
		"Kantoku (1044–1046)",
		"Eishō (1046–1053)",
		"Tengi (1053–1058)",
		"Kōhei (1058–1065)",
		"Jiryaku (1065–1069)",
		"Enkyū (1069–1074)",
		"Shōho (1074–1077)",
		"Shōryaku (1077–1081)",
		"Eihō (1081–1084)",
		"Ōtoku (1084–1087)",
		"Kanji (1087–1094)",
		"Kahō (1094–1096)",
		"Eichō (1096–1097)",
		"Jōtoku (1097–1099)",
		"Kōwa (1099–1104)",
		"Chōji (1104–1106)",
		"Kashō (1106–1108)",
		"Tennin (1108–1110)",
		"Ten-ei (1110-1113)",
		"Eikyū (1113–1118)",
		"Gen’ei (1118–1120)",
		"Hōan (1120–1124)",
		"Tenji (1124–1126)",
		"Daiji (1126–1131)",
		"Tenshō (1131–1132)",
		"Chōshō (1132–1135)",
		"Hōen (1135–1141)",
		"Eiji (1141–1142)",
		"Kōji (1142–1144)",
		"Ten’yō (1144–1145)",
		"Kyūan (1145–1151)",
		"Ninpei (1151–1154)",
		"Kyūju (1154–1156)",
		"Hōgen (1156–1159)",
		"Heiji (1159–1160)",
		"Eiryaku (1160–1161)",
		"Ōho (1161–1163)",
		"Chōkan (1163–1165)",
		"Eiman (1165–1166)",
		"Nin’an (1166–1169)",
		"Kaō (1169–1171)",
		"Shōan (1171–1175)",
		"Angen (1175–1177)",
		"Jishō (1177–1181)",
		"Yōwa (1181–1182)",
		"Juei (1182–1184)",
		"Genryaku (1184–1185)",
		"Bunji (1185–1190)",
		"Kenkyū (1190–1199)",
		"Shōji (1199–1201)",
		"Kennin (1201–1204)",
		"Genkyū (1204–1206)",
		"Ken’ei (1206–1207)",
		"Jōgen (1207–1211)",
		"Kenryaku (1211–1213)",
		"Kenpō (1213–1219)",
		"Jōkyū (1219–1222)",
		"Jōō (1222–1224)",
		"Gennin (1224–1225)",
		"Karoku (1225–1227)",
		"Antei (1227–1229)",
		"Kanki (1229–1232)",
		"Jōei (1232–1233)",
		"Tenpuku (1233–1234)",
		"Bunryaku (1234–1235)",
		"Katei (1235–1238)",
		"Ryakunin (1238–1239)",
		"En’ō (1239–1240)",
		"Ninji (1240–1243)",
		"Kangen (1243–1247)",
		"Hōji (1247–1249)",
		"Kenchō (1249–1256)",
		"Kōgen (1256–1257)",
		"Shōka (1257–1259)",
		"Shōgen (1259–1260)",
		"Bun’ō (1260–1261)",
		"Kōchō (1261–1264)",
		"Bun’ei (1264–1275)",
		"Kenji (1275–1278)",
		"Kōan (1278–1288)",
		"Shōō (1288–1293)",
		"Einin (1293–1299)",
		"Shōan (1299–1302)",
		"Kengen (1302–1303)",
		"Kagen (1303–1306)",
		"Tokuji (1306–1308)",
		"Enkyō (1308–1311)",
		"Ōchō (1311–1312)",
		"Shōwa (1312–1317)",
		"Bunpō (1317–1319)",
		"Genō (1319–1321)",
		"Genkō (1321–1324)",
		"Shōchū (1324–1326)",
		"Karyaku (1326–1329)",
		"Gentoku (1329–1331)",
		"Genkō (1331–1334)",
		"Kenmu (1334–1336)",
		"Engen (1336–1340)",
		"Kōkoku (1340–1346)",
		"Shōhei (1346–1370)",
		"Kentoku (1370–1372)",
		"Bunchū (1372–1375)",
		"Tenju (1375–1379)",
		"Kōryaku (1379–1381)",
		"Kōwa (1381–1384)",
		"Genchū (1384–1392)",
		"Meitoku (1384–1387)",
		"Kakei (1387–1389)",
		"Kōō (1389–1390)",
		"Meitoku (1390–1394)",
		"Ōei (1394–1428)",
		"Shōchō (1428–1429)",
		"Eikyō (1429–1441)",
		"Kakitsu (1441–1444)",
		"Bun’an (1444–1449)",
		"Hōtoku (1449–1452)",
		"Kyōtoku (1452–1455)",
		"Kōshō (1455–1457)",
		"Chōroku (1457–1460)",
		"Kanshō (1460–1466)",
		"Bunshō (1466–1467)",
		"Ōnin (1467–1469)",
		"Bunmei (1469–1487)",
		"Chōkyō (1487–1489)",
		"Entoku (1489–1492)",
		"Meiō (1492–1501)",
		"Bunki (1501–1504)",
		"Eishō (1504–1521)",
		"Taiei (1521–1528)",
		"Kyōroku (1528–1532)",
		"Tenbun (1532–1555)",
		"Kōji (1555–1558)",
		"Eiroku (1558–1570)",
		"Genki (1570–1573)",
		"Tenshō (1573–1592)",
		"Bunroku (1592–1596)",
		"Keichō (1596–1615)",
		"Genna (1615–1624)",
		"Kan’ei (1624–1644)",
		"Shōho (1644–1648)",
		"Keian (1648–1652)",
		"Jōō (1652–1655)",
		"Meireki (1655–1658)",
		"Manji (1658–1661)",
		"Kanbun (1661–1673)",
		"Enpō (1673–1681)",
		"Tenna (1681–1684)",
		"Jōkyō (1684–1688)",
		"Genroku (1688–1704)",
		"Hōei (1704–1711)",
		"Shōtoku (1711–1716)",
		"Kyōhō (1716–1736)",
		"Genbun (1736–1741)",
		"Kanpō (1741–1744)",
		"Enkyō (1744–1748)",
		"Kan’en (1748–1751)",
		"Hōreki (1751–1764)",
		"Meiwa (1764–1772)",
		"An’ei (1772–1781)",
		"Tenmei (1781–1789)",
		"Kansei (1789–1801)",
		"Kyōwa (1801–1804)",
		"Bunka (1804–1818)",
		"Bunsei (1818–1830)",
		"Tenpō (1830–1844)",
		"Kōka (1844–1848)",
		"Kaei (1848–1854)",
		"Ansei (1854–1860)",
		"Man’en (1860–1861)",
		"Bunkyū (1861–1864)",
		"Genji (1864–1865)",
		"Keiō (1865–1868)",
		"Meiji",
		"Taishō",
		"Shōwa",
		"Heisei"
	],
	"field-weekOfMonth": "týden v měsíci",
	"field-month-short": "měs.",
	"dateFormatItem-GyMMMEd": "E d. M. y G",
	"dateFormatItem-yyyyMd": "d. M. y GGGGG",
	"field-day": "den",
	"field-dayOfYear-short": "den v r.",
	"field-year-relative+-1": "minulý rok",
	"field-sat-short-relative+-1": "minulou sobotu",
	"dateFormatItem-yyyyMMMMd": "d. MMMM y G",
	"field-hour-relative+0": "tuto hodinu",
	"dateFormatItem-yyyyMEd": "E d. M. y GGGGG",
	"field-second-short-relative+0": "nyní",
	"field-wed-relative+-1": "minulou středu",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "minulou sobotu",
	"field-second": "sekunda",
	"dateFormat-long": "d. MMMM y G",
	"dateFormatItem-GyMMMd": "d. M. y G",
	"field-hour-short-relative+0": "tuto hodinu",
	"field-quarter": "čtvrtletí",
	"field-week-short": "týd.",
	"field-day-narrow-relative+0": "dnes",
	"field-day-narrow-relative+1": "zítra",
	"field-day-narrow-relative+2": "pozítří",
	"dateFormatItem-yyyyMMMMEd": "E d. MMMM y G",
	"field-tue-short-relative+0": "toto úterý",
	"field-tue-short-relative+1": "příští úterý",
	"field-month-short-relative+-1": "minulý měs.",
	"field-mon-relative+-1": "minulé pondělí",
	"dateFormatItem-GyMMM": "LLLL y G",
	"field-month": "měsíc",
	"field-day-narrow": "den",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min",
	"field-dayperiod": "část dne",
	"field-sat-short-relative+0": "tuto sobotu",
	"field-sat-short-relative+1": "příští sobotu",
	"dateFormat-medium": "d. M. y G",
	"dateFormatItem-yyyyMMMM": "LLLL y G",
	"eraAbbr": [
		"Taika (645–650)",
		"Hakuchi (650–671)",
		"Hakuhō (672–686)",
		"Shuchō (686–701)",
		"Taihō (701–704)",
		"Keiun (704–708)",
		"Wadō (708–715)",
		"Reiki (715–717)",
		"Yōrō (717–724)",
		"Jinki (724–729)",
		"Tenpyō (729–749)",
		"Tenpyō-kampō (749-749)",
		"Tenpyō-shōhō (749-757)",
		"Tenpyō-hōji (757-765)",
		"Tenpyō-jingo (765-767)",
		"Jingo-keiun (767-770)",
		"Hōki (770–780)",
		"Ten-ō (781-782)",
		"Enryaku (782–806)",
		"Daidō (806–810)",
		"Kōnin (810–824)",
		"Tenchō (824–834)",
		"Jōwa (834–848)",
		"Kajō (848–851)",
		"Ninju (851–854)",
		"Saikō (854–857)",
		"Ten-an (857-859)",
		"Jōgan (859–877)",
		"Gangyō (877–885)",
		"Ninna (885–889)",
		"Kanpyō (889–898)",
		"Shōtai (898–901)",
		"Engi (901–923)",
		"Enchō (923–931)",
		"Jōhei (931–938)",
		"Tengyō (938–947)",
		"Tenryaku (947–957)",
		"Tentoku (957–961)",
		"Ōwa (961–964)",
		"Kōhō (964–968)",
		"Anna (968–970)",
		"Tenroku (970–973)",
		"Ten’en (973–976)",
		"Jōgen (976–978)",
		"Tengen (978–983)",
		"Eikan (983–985)",
		"Kanna (985–987)",
		"Eien (987–989)",
		"Eiso (989–990)",
		"Shōryaku (990–995)",
		"Chōtoku (995–999)",
		"Chōhō (999–1004)",
		"Kankō (1004–1012)",
		"Chōwa (1012–1017)",
		"Kannin (1017–1021)",
		"Jian (1021–1024)",
		"Manju (1024–1028)",
		"Chōgen (1028–1037)",
		"Chōryaku (1037–1040)",
		"Chōkyū (1040–1044)",
		"Kantoku (1044–1046)",
		"Eishō (1046–1053)",
		"Tengi (1053–1058)",
		"Kōhei (1058–1065)",
		"Jiryaku (1065–1069)",
		"Enkyū (1069–1074)",
		"Shōho (1074–1077)",
		"Shōryaku (1077–1081)",
		"Eihō (1081–1084)",
		"Ōtoku (1084–1087)",
		"Kanji (1087–1094)",
		"Kahō (1094–1096)",
		"Eichō (1096–1097)",
		"Jōtoku (1097–1099)",
		"Kōwa (1099–1104)",
		"Chōji (1104–1106)",
		"Kashō (1106–1108)",
		"Tennin (1108–1110)",
		"Ten-ei (1110-1113)",
		"Eikyū (1113–1118)",
		"Gen’ei (1118–1120)",
		"Hōan (1120–1124)",
		"Tenji (1124–1126)",
		"Daiji (1126–1131)",
		"Tenshō (1131–1132)",
		"Chōshō (1132–1135)",
		"Hōen (1135–1141)",
		"Eiji (1141–1142)",
		"Kōji (1142–1144)",
		"Ten’yō (1144–1145)",
		"Kyūan (1145–1151)",
		"Ninpei (1151–1154)",
		"Kyūju (1154–1156)",
		"Hōgen (1156–1159)",
		"Heiji (1159–1160)",
		"Eiryaku (1160–1161)",
		"Ōho (1161–1163)",
		"Chōkan (1163–1165)",
		"Eiman (1165–1166)",
		"Nin’an (1166–1169)",
		"Kaō (1169–1171)",
		"Shōan (1171–1175)",
		"Angen (1175–1177)",
		"Jishō (1177–1181)",
		"Yōwa (1181–1182)",
		"Juei (1182–1184)",
		"Genryaku (1184–1185)",
		"Bunji (1185–1190)",
		"Kenkyū (1190–1199)",
		"Shōji (1199–1201)",
		"Kennin (1201–1204)",
		"Genkyū (1204–1206)",
		"Ken’ei (1206–1207)",
		"Jōgen (1207–1211)",
		"Kenryaku (1211–1213)",
		"Kenpō (1213–1219)",
		"Jōkyū (1219–1222)",
		"Jōō (1222–1224)",
		"Gennin (1224–1225)",
		"Karoku (1225–1227)",
		"Antei (1227–1229)",
		"Kanki (1229–1232)",
		"Jōei (1232–1233)",
		"Tenpuku (1233–1234)",
		"Bunryaku (1234–1235)",
		"Katei (1235–1238)",
		"Ryakunin (1238–1239)",
		"En’ō (1239–1240)",
		"Ninji (1240–1243)",
		"Kangen (1243–1247)",
		"Hōji (1247–1249)",
		"Kenchō (1249–1256)",
		"Kōgen (1256–1257)",
		"Shōka (1257–1259)",
		"Shōgen (1259–1260)",
		"Bun’ō (1260–1261)",
		"Kōchō (1261–1264)",
		"Bun’ei (1264–1275)",
		"Kenji (1275–1278)",
		"Kōan (1278–1288)",
		"Shōō (1288–1293)",
		"Einin (1293–1299)",
		"Shōan (1299–1302)",
		"Kengen (1302–1303)",
		"Kagen (1303–1306)",
		"Tokuji (1306–1308)",
		"Enkyō (1308–1311)",
		"Ōchō (1311–1312)",
		"Shōwa (1312–1317)",
		"Bunpō (1317–1319)",
		"Genō (1319–1321)",
		"Genkō (1321–1324)",
		"Shōchū (1324–1326)",
		"Karyaku (1326–1329)",
		"Gentoku (1329–1331)",
		"Genkō (1331–1334)",
		"Kenmu (1334–1336)",
		"Engen (1336–1340)",
		"Kōkoku (1340–1346)",
		"Shōhei (1346–1370)",
		"Kentoku (1370–1372)",
		"Bunchū (1372–1375)",
		"Tenju (1375–1379)",
		"Kōryaku (1379–1381)",
		"Kōwa (1381–1384)",
		"Genchū (1384–1392)",
		"Meitoku (1384–1387)",
		"Kakei (1387–1389)",
		"Kōō (1389–1390)",
		"Meitoku (1390–1394)",
		"Ōei (1394–1428)",
		"Shōchō (1428–1429)",
		"Eikyō (1429–1441)",
		"Kakitsu (1441–1444)",
		"Bun’an (1444–1449)",
		"Hōtoku (1449–1452)",
		"Kyōtoku (1452–1455)",
		"Kōshō (1455–1457)",
		"Chōroku (1457–1460)",
		"Kanshō (1460–1466)",
		"Bunshō (1466–1467)",
		"Ōnin (1467–1469)",
		"Bunmei (1469–1487)",
		"Chōkyō (1487–1489)",
		"Entoku (1489–1492)",
		"Meiō (1492–1501)",
		"Bunki (1501–1504)",
		"Eishō (1504–1521)",
		"Taiei (1521–1528)",
		"Kyōroku (1528–1532)",
		"Tenbun (1532–1555)",
		"Kōji (1555–1558)",
		"Eiroku (1558–1570)",
		"Genki (1570–1573)",
		"Tenshō (1573–1592)",
		"Bunroku (1592–1596)",
		"Keichō (1596–1615)",
		"Genna (1615–1624)",
		"Kan’ei (1624–1644)",
		"Shōho (1644–1648)",
		"Keian (1648–1652)",
		"Jōō (1652–1655)",
		"Meireki (1655–1658)",
		"Manji (1658–1661)",
		"Kanbun (1661–1673)",
		"Enpō (1673–1681)",
		"Tenna (1681–1684)",
		"Jōkyō (1684–1688)",
		"Genroku (1688–1704)",
		"Hōei (1704–1711)",
		"Shōtoku (1711–1716)",
		"Kyōhō (1716–1736)",
		"Genbun (1736–1741)",
		"Kanpō (1741–1744)",
		"Enkyō (1744–1748)",
		"Kan’en (1748–1751)",
		"Hōreki (1751–1764)",
		"Meiwa (1764–1772)",
		"An’ei (1772–1781)",
		"Tenmei (1781–1789)",
		"Kansei (1789–1801)",
		"Kyōwa (1801–1804)",
		"Bunka (1804–1818)",
		"Bunsei (1818–1830)",
		"Tenpō (1830–1844)",
		"Kōka (1844–1848)",
		"Kaei (1848–1854)",
		"Ansei (1854–1860)",
		"Man’en (1860–1861)",
		"Bunkyū (1861–1864)",
		"Genji (1864–1865)",
		"Keiō (1865–1868)",
		"Meiji",
		"Taishō",
		"Shōwa",
		"Heisei"
	],
	"dateFormatItem-yyyyM": "M/y GGGGG",
	"field-second-narrow": "s",
	"field-mon-relative+0": "toto pondělí",
	"field-mon-relative+1": "příští pondělí",
	"field-day-narrow-relative+-1": "včera",
	"field-year-short": "r.",
	"field-day-narrow-relative+-2": "předevčírem",
	"field-quarter-relative+-1": "minulé čtvrtletí",
	"dateFormatItem-yyyyMMMd": "d. M. y G",
	"field-dayperiod-narrow": "část d.",
	"field-week-narrow-relative+-1": "minulý týd.",
	"field-dayOfYear": "den v roce",
	"field-sat-relative+-1": "minulou sobotu",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "d. M.",
	"field-hour": "hodina",
	"field-minute-narrow-relative+0": "tuto minutu",
	"dateFormat-full": "EEEE, d. MMMM y G",
	"field-month-relative+-1": "minulý měsíc",
	"field-quarter-short": "Q",
	"field-sat-narrow-relative+0": "tuto sobotu",
	"field-fri-relative+0": "tento pátek",
	"field-sat-narrow-relative+1": "příští sobotu",
	"field-fri-relative+1": "příští pátek",
	"field-month-narrow-relative+0": "tento měs.",
	"field-month-narrow-relative+1": "příští měs.",
	"field-sun-short-relative+0": "tuto neděli",
	"field-sun-short-relative+1": "příští neděli",
	"field-week-relative+-1": "minulý týden",
	"field-quarter-short-relative+-1": "minulé čtvrtletí",
	"field-minute-short-relative+0": "tuto minutu",
	"field-quarter-relative+0": "toto čtvrtletí",
	"field-minute-relative+0": "tuto minutu",
	"field-quarter-relative+1": "příští čtvrtletí",
	"field-wed-short-relative+-1": "minulou středu",
	"dateFormat-short": "dd.MM.yy GGGGG",
	"field-year-narrow-relative+-1": "minulý rok",
	"field-thu-short-relative+-1": "minulý čtvrtek",
	"dateFormatItem-yyyyMMMEd": "E d. M. y G",
	"field-mon-narrow-relative+-1": "minulé pondělí",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "minulý čtvrtek",
	"dateFormatItem-E": "ccc",
	"field-weekOfMonth-short": "týd. v m.",
	"field-tue-narrow-relative+-1": "minulé úterý",
	"dateFormatItem-yyyy": "y G",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "tuto středu",
	"field-wed-short-relative+1": "příští středu",
	"field-sun-relative+-1": "minulou neděli",
	"dateFormatItem-MMMMEd": "E d. MMMM",
	"dateTimeFormat-full": "{1} {0}",
	"field-second-narrow-relative+0": "nyní",
	"dateFormatItem-d": "d.",
	"field-weekday": "den v týdnu",
	"field-day-short-relative+0": "dnes",
	"field-quarter-narrow-relative+0": "toto čtvrtletí",
	"field-day-short-relative+1": "zítra",
	"field-sat-relative+0": "tuto sobotu",
	"field-quarter-narrow-relative+1": "příští čtvrtletí",
	"field-day-short-relative+2": "pozítří",
	"field-sat-relative+1": "příští sobotu",
	"field-week-short-relative+0": "tento týd.",
	"field-week-short-relative+1": "příští týd.",
	"dateFormatItem-GyMMMMEd": "E d. MMMM y G",
	"field-dayOfYear-narrow": "d. v r.",
	"field-month-short-relative+0": "tento měs.",
	"field-month-short-relative+1": "příští měs.",
	"field-weekdayOfMonth-short": "den týd. v měs.",
	"dateFormatItem-MEd": "E d. M.",
	"field-zone-narrow": "pásmo",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "tento čtvrtek",
	"field-sun-narrow-relative+-1": "minulou neděli",
	"field-mon-short-relative+-1": "minulé pondělí",
	"field-thu-narrow-relative+1": "příští čtvrtek",
	"field-thu-relative+0": "tento čtvrtek",
	"field-thu-relative+1": "příští čtvrtek",
	"field-fri-short-relative+-1": "minulý pátek",
	"field-thu-relative+-1": "minulý čtvrtek",
	"field-week": "týden",
	"dateFormatItem-Ed": "E d.",
	"field-wed-narrow-relative+0": "tuto středu",
	"field-wed-narrow-relative+1": "příští středu",
	"field-quarter-narrow-relative+-1": "minulé čtvrtletí",
	"field-year-short-relative+0": "tento rok",
	"dateFormatItem-yyyyMMM": "LLLL y G",
	"field-dayperiod-short": "část dne",
	"field-year-short-relative+1": "příští rok",
	"field-fri-short-relative+0": "tento pátek",
	"field-fri-short-relative+1": "příští pátek",
	"field-week-short-relative+-1": "minulý týd.",
	"dateFormatItem-GyMMMMd": "d. MMMM y G",
	"field-hour-narrow-relative+0": "tuto hodinu",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "h",
	"field-zone-short": "čas. pásmo",
	"field-month-narrow": "měs.",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "minulý pátek",
	"field-year-relative+0": "tento rok",
	"field-year-relative+1": "příští rok",
	"field-era-narrow": "let.",
	"field-fri-relative+-1": "minulý pátek",
	"eraNarrow": [
		"Taika (645–650)",
		"Hakuchi (650–671)",
		"Hakuhō (672–686)",
		"Shuchō (686–701)",
		"Taihō (701–704)",
		"Keiun (704–708)",
		"Wadō (708–715)",
		"Reiki (715–717)",
		"Yōrō (717–724)",
		"Jinki (724–729)",
		"Tenpyō (729–749)",
		"Tenpyō-kampō (749-749)",
		"Tenpyō-shōhō (749-757)",
		"Tenpyō-hōji (757-765)",
		"Tenpyō-jingo (765-767)",
		"Jingo-keiun (767-770)",
		"Hōki (770–780)",
		"Ten-ō (781-782)",
		"Enryaku (782–806)",
		"Daidō (806–810)",
		"Kōnin (810–824)",
		"Tenchō (824–834)",
		"Jōwa (834–848)",
		"Kajō (848–851)",
		"Ninju (851–854)",
		"Saikō (854–857)",
		"Ten-an (857-859)",
		"Jōgan (859–877)",
		"Gangyō (877–885)",
		"Ninna (885–889)",
		"Kanpyō (889–898)",
		"Shōtai (898–901)",
		"Engi (901–923)",
		"Enchō (923–931)",
		"Jōhei (931–938)",
		"Tengyō (938–947)",
		"Tenryaku (947–957)",
		"Tentoku (957–961)",
		"Ōwa (961–964)",
		"Kōhō (964–968)",
		"Anna (968–970)",
		"Tenroku (970–973)",
		"Ten’en (973–976)",
		"Jōgen (976–978)",
		"Tengen (978–983)",
		"Eikan (983–985)",
		"Kanna (985–987)",
		"Eien (987–989)",
		"Eiso (989–990)",
		"Shōryaku (990–995)",
		"Chōtoku (995–999)",
		"Chōhō (999–1004)",
		"Kankō (1004–1012)",
		"Chōwa (1012–1017)",
		"Kannin (1017–1021)",
		"Jian (1021–1024)",
		"Manju (1024–1028)",
		"Chōgen (1028–1037)",
		"Chōryaku (1037–1040)",
		"Chōkyū (1040–1044)",
		"Kantoku (1044–1046)",
		"Eishō (1046–1053)",
		"Tengi (1053–1058)",
		"Kōhei (1058–1065)",
		"Jiryaku (1065–1069)",
		"Enkyū (1069–1074)",
		"Shōho (1074–1077)",
		"Shōryaku (1077–1081)",
		"Eihō (1081–1084)",
		"Ōtoku (1084–1087)",
		"Kanji (1087–1094)",
		"Kahō (1094–1096)",
		"Eichō (1096–1097)",
		"Jōtoku (1097–1099)",
		"Kōwa (1099–1104)",
		"Chōji (1104–1106)",
		"Kashō (1106–1108)",
		"Tennin (1108–1110)",
		"Ten-ei (1110-1113)",
		"Eikyū (1113–1118)",
		"Gen’ei (1118–1120)",
		"Hōan (1120–1124)",
		"Tenji (1124–1126)",
		"Daiji (1126–1131)",
		"Tenshō (1131–1132)",
		"Chōshō (1132–1135)",
		"Hōen (1135–1141)",
		"Eiji (1141–1142)",
		"Kōji (1142–1144)",
		"Ten’yō (1144–1145)",
		"Kyūan (1145–1151)",
		"Ninpei (1151–1154)",
		"Kyūju (1154–1156)",
		"Hōgen (1156–1159)",
		"Heiji (1159–1160)",
		"Eiryaku (1160–1161)",
		"Ōho (1161–1163)",
		"Chōkan (1163–1165)",
		"Eiman (1165–1166)",
		"Nin’an (1166–1169)",
		"Kaō (1169–1171)",
		"Shōan (1171–1175)",
		"Angen (1175–1177)",
		"Jishō (1177–1181)",
		"Yōwa (1181–1182)",
		"Juei (1182–1184)",
		"Genryaku (1184–1185)",
		"Bunji (1185–1190)",
		"Kenkyū (1190–1199)",
		"Shōji (1199–1201)",
		"Kennin (1201–1204)",
		"Genkyū (1204–1206)",
		"Ken’ei (1206–1207)",
		"Jōgen (1207–1211)",
		"Kenryaku (1211–1213)",
		"Kenpō (1213–1219)",
		"Jōkyū (1219–1222)",
		"Jōō (1222–1224)",
		"Gennin (1224–1225)",
		"Karoku (1225–1227)",
		"Antei (1227–1229)",
		"Kanki (1229–1232)",
		"Jōei (1232–1233)",
		"Tenpuku (1233–1234)",
		"Bunryaku (1234–1235)",
		"Katei (1235–1238)",
		"Ryakunin (1238–1239)",
		"En’ō (1239–1240)",
		"Ninji (1240–1243)",
		"Kangen (1243–1247)",
		"Hōji (1247–1249)",
		"Kenchō (1249–1256)",
		"Kōgen (1256–1257)",
		"Shōka (1257–1259)",
		"Shōgen (1259–1260)",
		"Bun’ō (1260–1261)",
		"Kōchō (1261–1264)",
		"Bun’ei (1264–1275)",
		"Kenji (1275–1278)",
		"Kōan (1278–1288)",
		"Shōō (1288–1293)",
		"Einin (1293–1299)",
		"Shōan (1299–1302)",
		"Kengen (1302–1303)",
		"Kagen (1303–1306)",
		"Tokuji (1306–1308)",
		"Enkyō (1308–1311)",
		"Ōchō (1311–1312)",
		"Shōwa (1312–1317)",
		"Bunpō (1317–1319)",
		"Genō (1319–1321)",
		"Genkō (1321–1324)",
		"Shōchū (1324–1326)",
		"Karyaku (1326–1329)",
		"Gentoku (1329–1331)",
		"Genkō (1331–1334)",
		"Kenmu (1334–1336)",
		"Engen (1336–1340)",
		"Kōkoku (1340–1346)",
		"Shōhei (1346–1370)",
		"Kentoku (1370–1372)",
		"Bunchū (1372–1375)",
		"Tenju (1375–1379)",
		"Kōryaku (1379–1381)",
		"Kōwa (1381–1384)",
		"Genchū (1384–1392)",
		"Meitoku (1384–1387)",
		"Kakei (1387–1389)",
		"Kōō (1389–1390)",
		"Meitoku (1390–1394)",
		"Ōei (1394–1428)",
		"Shōchō (1428–1429)",
		"Eikyō (1429–1441)",
		"Kakitsu (1441–1444)",
		"Bun’an (1444–1449)",
		"Hōtoku (1449–1452)",
		"Kyōtoku (1452–1455)",
		"Kōshō (1455–1457)",
		"Chōroku (1457–1460)",
		"Kanshō (1460–1466)",
		"Bunshō (1466–1467)",
		"Ōnin (1467–1469)",
		"Bunmei (1469–1487)",
		"Chōkyō (1487–1489)",
		"Entoku (1489–1492)",
		"Meiō (1492–1501)",
		"Bunki (1501–1504)",
		"Eishō (1504–1521)",
		"Taiei (1521–1528)",
		"Kyōroku (1528–1532)",
		"Tenbun (1532–1555)",
		"Kōji (1555–1558)",
		"Eiroku (1558–1570)",
		"Genki (1570–1573)",
		"Tenshō (1573–1592)",
		"Bunroku (1592–1596)",
		"Keichō (1596–1615)",
		"Genna (1615–1624)",
		"Kan’ei (1624–1644)",
		"Shōho (1644–1648)",
		"Keian (1648–1652)",
		"Jōō (1652–1655)",
		"Meireki (1655–1658)",
		"Manji (1658–1661)",
		"Kanbun (1661–1673)",
		"Enpō (1673–1681)",
		"Tenna (1681–1684)",
		"Jōkyō (1684–1688)",
		"Genroku (1688–1704)",
		"Hōei (1704–1711)",
		"Shōtoku (1711–1716)",
		"Kyōhō (1716–1736)",
		"Genbun (1736–1741)",
		"Kanpō (1741–1744)",
		"Enkyō (1744–1748)",
		"Kan’en (1748–1751)",
		"Hōreki (1751–1764)",
		"Meiwa (1764–1772)",
		"An’ei (1772–1781)",
		"Tenmei (1781–1789)",
		"Kansei (1789–1801)",
		"Kyōwa (1801–1804)",
		"Bunka (1804–1818)",
		"Bunsei (1818–1830)",
		"Tenpō (1830–1844)",
		"Kōka (1844–1848)",
		"Kaei (1848–1854)",
		"Ansei (1854–1860)",
		"Man’en (1860–1861)",
		"Bunkyū (1861–1864)",
		"Genji (1864–1865)",
		"Keiō (1865–1868)",
		"M",
		"T",
		"S",
		"H"
	],
	"field-tue-short-relative+-1": "minulé úterý",
	"field-minute-narrow": "min",
	"field-mon-narrow-relative+0": "toto pondělí",
	"field-mon-narrow-relative+1": "příští pondělí",
	"field-year-short-relative+-1": "minulý rok",
	"field-zone": "časové pásmo",
	"dateFormatItem-MMMEd": "E d. M.",
	"field-weekOfMonth-narrow": "týd. v m.",
	"field-weekday-narrow": "d. v týd.",
	"field-quarter-narrow": "Q",
	"field-sun-short-relative+-1": "minulou neděli",
	"field-day-relative+-1": "včera",
	"field-day-relative+-2": "předevčírem",
	"field-weekday-short": "den v týd.",
	"field-sun-relative+0": "tuto neděli",
	"field-sun-relative+1": "příští neděli",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "den",
	"field-week-narrow": "týd.",
	"field-era": "letopočet",
	"field-fri-narrow-relative+0": "tento pátek",
	"field-fri-narrow-relative+1": "příští pátek"
}
//end v1.x content
);